/******************************************************************************************************

	NSViewOverlays.h
	
 ******************************************************************************************************

	Author:			Peter Baumgartner		Tel:  (+4989) 649-43875
					Rosskopfstr. 20			Mail: peter@baumgartner.com
					82031 Grnwald			
					Germany					
	
					Copyright  2006 by Peter Baumgartner - All Rights Reserved

 ******************************************************************************************************/

/******************************************************************************************************
	READ ME
 ******************************************************************************************************/

	#pragma mark READ ME

	// This category on NSView can create views overlays by dynamically creating child windows...


	
/******************************************************************************************************
	INCLUDES
 ******************************************************************************************************/

	#pragma mark INCLUDES
	
	#import <AppKit/AppKit.h>



/******************************************************************************************************
	NSView (Overlays)
 ******************************************************************************************************/

	#pragma mark

	@interface NSView (Overlays)
	
	- (void) addOverlayWithView:(NSView <NSWindowDelegate> *)inOverlayView
						  frame:(NSRect)inFrame
				   resizingMask:(NSUInteger)inRezisingMask
						ordered:(NSWindowOrderingMode)inOrdered;

	- (void) removeOverlayView:(NSView*)inOverlayView;
	
	- (void) viewWillBecomeOverlay;
	- (void) viewDidBecomeOverlay;
	- (void) viewWillResignOverlay;
	- (void) viewDidResignOverlay;
	
	@end



/******************************************************************************************************
	OverlayChildWindow
 ******************************************************************************************************/

	#pragma mark

	@class OverlayHelperView;
	
	@interface OverlayChildWindow : NSPanel
	{
		NSWindow* _parentWindow;
		NSView* _parentView;
		OverlayHelperView* _helperView;
		NSWindowOrderingMode _order;
	}

	- (id) initWithContentRect:(NSRect)inContentRect 
		   styleMask:(NSUInteger)inStyle
		   backing:(NSBackingStoreType)inBufferingType 
		   defer:(BOOL)inFlag
		   parentView:(NSView*)inParentView 
		   helperView:(OverlayHelperView*)inHelperView 
		   ordered:(NSWindowOrderingMode)inOrdered;
		
	- (void) parentViewWillMoveToWindow:(NSWindow*)inWindow;
	- (void) parentViewDidMoveToWindow;
	- (void) resizeWithOldSuperviewSize:(NSSize)inBoundsSize;

	- (OverlayHelperView*) helperView;

	@end



/******************************************************************************************************
	OverlayHelperView
 ******************************************************************************************************/

	#pragma mark

	@interface OverlayHelperView : NSView
	{
		OverlayChildWindow* _childWindow;
	}
	
	- (void) setChildWindow:(OverlayChildWindow*)inWindow;
	
	@end



/******************************************************************************************************/
