/******************************************************************************************************

	UException.h
    Boinx Utility Framework
	
 ******************************************************************************************************

	Author:			Peter Baumgartner		Tel:  (+4989) 649-43875
					Rosskopfstr. 20			Mail: peter@baumgartner.com
					82031 Grünwald			
					Germany					
	
	Description:	Exception utils...
					
					Copyright © 2005 by Peter Baumgartner - All Rights Reserved

 ******************************************************************************************************/

/******************************************************************************************************
	READ ME
 ******************************************************************************************************/

	#pragma mark READ ME

	// This file supplies a couple of convenience macros for throwing excpetions. Please use
	// these macros instead of the raw Obj-C exception classes, as the macros include a lot
	// more useful information ...

	// The class UException adds a wrapper around the Obj-C classes and also supplies some
	// additional features like section names and alert dialogs. For each of these features
	// stack based classes (which can be nested) are supplied. See the example below for usage...
	
	//		void foobar()
	//		{
	//			StExceptionSectionName section("foobar");
	//			StExceptionDisplaysAlert alert(NO);
	//			OSStatus err = noErr;
	//			
	//			@try
	//			{
	//				err = SomeFunction();
	//				BXThrowErr(err,"SomeFunction");
	//				
	//				err = AnotherFunction();
	//				BXThrowErr(err,"AnotherFunction");
	//			}
	//			
	//			@catch (BXException* exception)
	//			{
	//				[exception log];
	//			}
	//			
	//			@finally
	//			{
	//				// Cleanup...
	//			}
	//		}


		
/******************************************************************************************************
	INCLUDES
 ******************************************************************************************************/

	#pragma mark INCLUDES

	#import "BXException.h"



/******************************************************************************************************
	MACROS
 ******************************************************************************************************/

	#pragma mark

	#ifndef BXThrow
	#define BXThrow(name,message)		UException::Throw(name,message,__FILE__,__LINE__)
	#endif
	
	#ifndef BXThrowErr
	#define BXThrowErr(err,message)		UException::ThrowErr(err,message,__FILE__,__LINE__)
	#endif
	
	
	
/******************************************************************************************************
	UException
 ******************************************************************************************************/

	#pragma mark
	
	class UException
	{
		public:
		
			static void SetSectionName(NSString* inName);
			static void SetSectionName(char* inName);
			static NSString* GetSectionName();
	
			static void SetDisplaysAlert(BOOL inDisplaysAlert);
			static BOOL GetDisplaysAlert();
	
			static void Throw(char* inName,char* inMessage,const char* inFile,NSInteger inLine);
			static void ThrowErr(OSStatus inErr,char* inMessage,const char* inFile,NSInteger inLine);

		protected:
		
			static NSString* sSectionName;
			static BOOL sDisplaysAlert;
	};

	

/******************************************************************************************************
	StExceptionSectionName
 ******************************************************************************************************/

	#pragma mark
	
	class StExceptionSectionName
	{
		public:
		
			StExceptionSectionName(NSString* inName);
			StExceptionSectionName(char* inName);
			~StExceptionSectionName();
			
		protected:
		
			NSString* _oldValue;
	};



/******************************************************************************************************
	StExceptionDisplaysAlert
 ******************************************************************************************************/

	#pragma mark
	
	class StExceptionDisplaysAlert
	{
		public:
		
			StExceptionDisplaysAlert(BOOL inDisplaysAlert);
			~StExceptionDisplaysAlert();
			
		protected:
		
			BOOL _oldValue;
	};



/******************************************************************************************************/
